const router = require("express").Router();
const multer = require("multer");
let Job = require("../models/job");

const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    cb(null, "uploads");
  },

  filename: (req, file, cb) => {
    cb(null, Date.now() + file.originalname);
  },
});

const upload = multer({
  storage: storage,
}).single("logo");

router.post("/add", upload, async (req, res) => {
  const newJob = new Job({
    jobID: req.body,
    title: req.body.title,
    company: req.body.company,
    location: req.body.location,
    workType: req.body.workType,
    term: req.body.term,
    salary: req.body.salary,
    duration: req.body.duration,
    deadline: req.body.deadline,
    logo: req.file.filename,
    responsibilities: req.body.responsibilities,
    qualifications: req.body.qualifications,
    aboutJob: req.body.aboutJob,
  });

  const totalNumberOfJobInDb = await Job.countDocuments();

  // convert number to string, so we can concatenate 0s easily...

  let numberToString = totalNumberOfJobInDb.toString();

  // If length of number string is less than 5 then add leading 0s in nuberToString

  if (numberToString.length < 3) {
    for (let i = numberToString.length; i < 3; i++) {
      numberToString = "0" + numberToString;
    }
  }

  newJob.jobID = `JID${numberToString}`;

  newJob
    .save()
    .then(() => {
      res.status(200).send({ status: "Job added" });
    })
    .catch((err) => {
      console.log(err);
      res
        .status(500)
        .send({ status: "Error with adding job", error: err.message });
    });
});

module.exports = router;