import React, {useState, useCallback} from 'react'
import DatePicker from "react-datepicker";
import ReactQuill from "react-quill";
import axios from 'axios';
import "react-datepicker/dist/react-datepicker.css";
import "react-quill/dist/quill.snow.css";
import './JobPosting.css'

function JobPosting() {
  const [title, setTitle] = useState("");
  const [company, setCompany] = useState("");
  const [location, setLocation] = useState("");
  const [workType, setWorkType] = useState("");
  const [term, setTerm] = useState("");
  const [salary, setSalary] = useState("");
  const [duration, setDuration] = useState("");
  const [deadline, setDeadline] = useState(new Date());
  const [logo, setLogo] = useState("");
  const [responsibilities, setResponsibilities] = useState("");
  const [qualifications, setQualifications] = useState("");
  const [aboutJob, setAboutJob] = useState("");

  const handleQuillChange = (content, setContent) => {
    // Remove <p> tags from the content
    const strippedContent = content.replace(/<p><\/p>/g, ""); // Remove empty <p> tags
    const finalContent = strippedContent.replace(/<p>(.*?)<\/p>/g, "$1\n"); // Preserve content structure

    setContent(finalContent.trim());
  };

  function sendData(e) {
    e.preventDefault();

    const formData = new FormData();
    formData.append("title", title);
    formData.append("company", company);
    formData.append("location", location);
    formData.append("workType", workType);
    formData.append("term", term);
    formData.append("salary", salary);
    formData.append("duration", duration);
    formData.append("deadline", deadline);
    formData.append("logo", logo);
    formData.append("responsibilities", responsibilities);
    formData.append("qualifications", qualifications);
    formData.append("aboutJob", aboutJob);

    axios
      .post("http://localhost:8070/job/add", formData, {
        headers: {
          "Content-Type": "multipart/form-data",
        },
      })
      .then(() => {
        alert("Job posted successfully");
        window.location.reload();
      })
      .catch((err) => {
        alert(err);
      });
  }

  return (
    <div className="jobPosting">
      <form className="form-jobPosting" onSubmit={sendData}>
        <div className="form-group">
          <label htmlFor="jobTitle">Job Title</label>
          <input
            type="text"
            className="form-control"
            id="jobTitle"
            required
            onChange={(e) => {
              setTitle(e.target.value);
            }}
          />
        </div>
        <div className="form-group">
          <label htmlFor="companyName">Company Name</label>
          <select
            className="form-control"
            id="companyName"
            required
            onChange={(e) => {
              setCompany(e.target.value);
            }}
          >
            <option value="" disabled selected>
              Select Company
            </option>
            <option>InstaHire</option>
          </select>
        </div>
        <div className="form-group">
          <label htmlFor="location">Location</label>
          <select
            className="form-control"
            id="location"
            required
            onChange={(e) => {
              setLocation(e.target.value);
            }}
          >
            <option value="" disabled selected>
              Select location
            </option>
            <option>No:365, Galle Road, Colombo 03</option>
          </select>
        </div>
        <div className="d-flex">
          <div className="form-group col-md-6">
            <label htmlFor="workType">Work Type</label>
            <select
              className="form-control"
              id="workType"
              required
              onChange={(e) => {
                setWorkType(e.target.value);
              }}
            >
              <option value="" disabled selected>
                Select work type
              </option>
              <option>On-site</option>
              <option>Hybrid</option>
              <option>Online</option>
            </select>
          </div>
          <div className="form-group col-md-6" style={{ paddingLeft: "5px" }}>
            <label htmlFor="term">Term</label>
            <select
              className="form-control"
              id="term"
              required
              onChange={(e) => {
                setTerm(e.target.value);
              }}
            >
              <option value="" disabled selected>
                Select term
              </option>
              <option>Full-time</option>
              <option>Part-time</option>
            </select>
          </div>
        </div>
        <div className="d-flex">
          <div className="form-group col-md-6">
            <label htmlFor="salary">Salary</label>
            <input
              type="number"
              className="form-control"
              id="salary"
              required
              onChange={(e) => {
                setSalary(e.target.value);
              }}
            />
          </div>
          <div className="form-group col-md-6" style={{ paddingLeft: "5px" }}>
            <label htmlFor="duration">Duration</label>
            <select
              className="form-control"
              id="duration"
              required
              onChange={(e) => {
                setDuration(e.target.value);
              }}
            >
              <option value="" disabled selected>
                Select duration
              </option>
              <option>6 months</option>
              <option>1 year</option>
              <option>2 year</option>
            </select>
          </div>
        </div>
        <div className="d-flex">
          <div className="form-group col-md-5">
            <label htmlFor="deadline">Deadline</label>
            <div>
              <DatePicker
                className="form-control"
                id="deadline"
                selected={deadline}
                onChange={(date) => setDeadline(date)}
              />
            </div>
          </div>
          <div
            className="form-group col-md-6 d-flex relative m-auto"
            style={{ marginLeft: "10px" }}
          >
            <label htmlFor="logo">Logo</label>
            <input
              type="file"
              name="logo"
              className="form-control-file"
              id="logo"
              required
              onChange={(e) => {
                setLogo(e.target.files[0]);
              }}
            />
          </div>
        </div>
        <div className="form-group">
          <label htmlFor="responsibilities">Key Responsibilities</label>
          <ReactQuill
            theme="snow"
            value={responsibilities}
            onChange={(content) =>
              handleQuillChange(content, setResponsibilities)
            }
          />
        </div>

        <div className="form-group">
          <label htmlFor="qualifications">Qualifications</label>
          <ReactQuill
            theme="snow"
            value={qualifications}
            onChange={(content) =>
              handleQuillChange(content, setQualifications)
            }
          />
        </div>

        <div className="form-group">
          <label htmlFor="aboutJob">About the Job</label>
          <ReactQuill
            theme="snow"
            value={aboutJob}
            onChange={(content) => handleQuillChange(content, setAboutJob)}
          />
        </div>
        <div style={{ paddingTop: "10px" }}>
          <button className="btn btn-primary" type="submit">
            Post Job
          </button>
        </div>
      </form>
    </div>
  );
}

export default JobPosting